==> elgg-1.11.0.zip: elgg-1.11.0/mod/file/languages/gl.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'file' => "Ficheiros",
	'file:user' => "Ficheiros de %s",
	'file:friends' => "Ficheiros dos contactos",
	'file:all' => "Ficheiros do siti",
	'file:edit' => "Editar o ficheir",
	'file:more' => "Máis ficheiros",
	'file:list' => "Vista de lista",
	'file:group' => "Ficheiros do grupo",
	'file:gallery' => "Vista de galería",
	'file:gallery_list' => "Vistas de lista ou galería.",
	'file:num_files' => "Número de ficheiros para mostrar",
	'file:user:gallery'=>'Ver a galería %s',
	'file:upload' => "Enviar un ficheir",
	'file:replace' => 'Substituír o contido do ficheiro (deixar baleiro para non cambiar o ficheiro)',
	'file:list:title' => "%s: %s %s",
	'file:title:friends' => "Dos contactos",

	'file:add' => 'Enviar un ficheiro',

	'file:file' => "Ficheir",

	'file:list:list' => 'Cambiar á vista de lista',
	'file:list:gallery' => 'Cambiar á vista de galería',

	'file:types' => "Tipo de ficheiros enviados",

	'file:type:' => 'Ficheiros',
	'file:type:all' => "Todos os ficheiros",
	'file:type:video' => "Vídeos",
	'file:type:document' => "Documentos",
	'file:type:audio' => "Sons",
	'file:type:image' => "Imaxes",
	'file:type:general' => "Xera",

	'file:user:type:video' => "Vídeos de %s",
	'file:user:type:document' => "Documentos de %s",
	'file:user:type:audio' => "Sons de %s",
	'file:user:type:image' => "Imaxes de %s",
	'file:user:type:general' => "Ficheiros xerais de %s",

	'file:friends:type:video' => "Vídeos dos contactos",
	'file:friends:type:document' => "Documentos dos contactos",
	'file:friends:type:audio' => "Sons dos contactos",
	'file:friends:type:image' => "Imaxes dos contactos",
	'file:friends:type:general' => "Ficheiros xerais dos contactos",

	'file:widget' => "Trebello de ficheiro",
	'file:widget:description' => "Presentar os últimos ficheiros",

	'groups:enablefiles' => 'Activar os ficheiros de grupo',

	'file:delete:confirm' => "Está seguro de que quere eliminar este ficheiro?",

	'file:upload_limit' => 'O tamaño máximo permitido para os ficheiros son %s.',

	'file:tagcloud' => "Nube de etiquetas",

	'file:display:number' => "Número de ficheiros para mostrar",

	'river:create:object:file' => '%s enviou o ficheiro %s',
	'river:comment:object:file' => '%s deixou un comentario no ficheiro %s',

	'item:object:file' => 'Ficheiros',

	'file:notify:summary' => 'Novo ficheiro: «%s»',
	'file:notify:subject' => 'Novo ficheiro: «%s»',
	'file:notify:body' =>
'%s enviou un novo ficheiro: %s

%s

Vexa e deixe un comentario no ficheiro:
%s
',

	/**
	 * Status messages
	 */

	'file:saved' => "Gardouse o ficheiro.",
	'file:deleted' => "Eliminouse o ficheiro.",

	/**
	 * Error messages
	 */

	'file:none' => "Non hai ficheiros",
	'file:uploadfailed' => "Non foi posíbel gardar o ficheiro",
	'file:downloadfailed' => "O ficheiro non está dispoñíbel nestes momentos",
	'file:deletefailed' => "Non foi posíbel eliminar o ficheiro.",
	'file:noaccess' => "Non ten permisos para cambiar o ficheiro.",
	'file:nofile' => "Debe seleccionar un ficheiro.",
);

==> elgg-3.0.5.zip: elgg-3.0.5/mod/file/languages/gl.php <==
<?php
return array(

	'item:object:file' => 'Ficheiros',
	'collection:object:file' => 'Files',
	'collection:object:file:all' => "All site files",
	'collection:object:file:owner' => "%s's files",
	'collection:object:file:friends' => "Friends' files",
	'collection:object:file:group' => "Group files",
	'add:object:file' => "Upload a file",
	'edit:object:file' => "Edit file",

	'file:more' => "Máis ficheiros",
	'file:list' => "Vista de lista",

	'file:num_files' => "Número de ficheiros para mostrar",
	'file:replace' => 'Substituír o contido do ficheiro (deixar baleiro para non cambiar o ficheiro)',
	'file:list:title' => "%s: %s %s",
	'file:title:friends' => "Dos contactos",

	'file:file' => "Ficheir",

	'file:list:list' => 'Cambiar á vista de lista',
	'file:list:gallery' => 'Cambiar á vista de galería',

	'file:types' => "Tipo de ficheiros enviados",

	'file:type:' => 'Ficheiros',
	'file:type:all' => "Todos os ficheiros",
	'file:type:video' => "Vídeos",
	'file:type:document' => "Documentos",
	'file:type:audio' => "Sons",
	'file:type:image' => "Imaxes",
	'file:type:general' => "Xera",

	'file:user:type:video' => "Vídeos de %s",
	'file:user:type:document' => "Documentos de %s",
	'file:user:type:audio' => "Sons de %s",
	'file:user:type:image' => "Imaxes de %s",
	'file:user:type:general' => "Ficheiros xerais de %s",

	'file:friends:type:video' => "Vídeos dos contactos",
	'file:friends:type:document' => "Documentos dos contactos",
	'file:friends:type:audio' => "Sons dos contactos",
	'file:friends:type:image' => "Imaxes dos contactos",
	'file:friends:type:general' => "Ficheiros xerais dos contactos",

	'widgets:filerepo:name' => "File widget",
	'widgets:filerepo:description' => "Showcase your latest files",

	'groups:tool:file' => 'Enable group files',

	'river:object:file:create' => '%s uploaded the file %s',
	'river:object:file:comment' => '%s commented on the file %s',

	'file:notify:summary' => 'Novo ficheiro: «%s»',
	'file:notify:subject' => 'Novo ficheiro: «%s»',
	'file:notify:body' => '%s uploaded a new file: %s

%s

View and comment on the file:
%s',

	/**
	 * Status messages
	 */

	'file:saved' => "The file was successfully saved.",
	'entity:delete:object:file:success' => "The file was successfully deleted.",

	/**
	 * Error messages
	 */

	'file:none' => "Non hai ficheiros",
	'file:uploadfailed' => "Non foi posíbel gardar o ficheiro",
	'file:noaccess' => "Non ten permisos para cambiar o ficheiro.",
	'file:cannotload' => "There was an error uploading the file",
);
